/*
 * Copyright 2007 - 2009 JEuclid, http://jeuclid.sf.net
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* $Id: package-info.java,v 81679af7f8ce 2009/04/09 06:59:25 maxberger $ */

/**
 * Contains the a fo preprocessor application and code.
 *
 *<p>
 *Please look at
 *<ul>
 *<li>{@link Main} for command line use.</li>
 *<li>{@link net.sourceforge.jeuclid.converter.Processor} for use in your own apps.</li>
 *</ul>
 *</p>
 */
package net.sourceforge.jeuclid.app.foprep;

